# textclean
Text cleaning

Navigate to the following directory:

cd base-textclean/textclean/src/

Then to run the "textclean.py" file type as below:

python [inputfile] [outputfile]

After the text processing the corresponding cleaned file will be generated in the folder.
